package com.fs.hospital.service;

import java.util.List;
import com.fs.hospital.domain.HospitalInspectItem;

/**
 * 检查Service接口
 * 
 * @author fs
 * @date 2024-03-26
 */
public interface IHospitalInspectItemService 
{
    /**
     * 查询检查
     * 
     * @param inspectId 检查主键
     * @return 检查
     */
    public HospitalInspectItem selectHospitalInspectItemByInspectId(Long inspectId);

    /**
     * 查询检查列表
     * 
     * @param hospitalInspectItem 检查
     * @return 检查集合
     */
    public List<HospitalInspectItem> selectHospitalInspectItemList(HospitalInspectItem hospitalInspectItem);

    /**
     * 新增检查
     * 
     * @param hospitalInspectItem 检查
     * @return 结果
     */
    public int insertHospitalInspectItem(HospitalInspectItem hospitalInspectItem);

    /**
     * 修改检查
     * 
     * @param hospitalInspectItem 检查
     * @return 结果
     */
    public int updateHospitalInspectItem(HospitalInspectItem hospitalInspectItem);

    /**
     * 批量删除检查
     * 
     * @param inspectIds 需要删除的检查主键集合
     * @return 结果
     */
    public int deleteHospitalInspectItemByInspectIds(Long[] inspectIds);

    /**
     * 删除检查信息
     * 
     * @param inspectId 检查主键
     * @return 结果
     */
    public int deleteHospitalInspectItemByInspectId(Long inspectId);
}
